@@ -58,11 +58,11 @@ App::Dochazka::REST::Model::Lock - lock data model
 
 =head1 VERSION
 
-Version 0.252
+Version 0.253
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.253';
 
 
 
@@ -118,18 +118,6 @@ our @EXPORT_OK = qw( );
 =head1 METHODS
 
 
-=head2 expurgate
-
-Non-destructively convert object into hashref
-
-=cut
-
-sub expurgate {
-    my ( $self ) = @_;
-    return App::Dochazka::REST::Model::Shared::expurgate( $self );
-}
-
-
 =head2 load_by_lid
 
 Instance method. Given an LID, loads a single lock into the object, rewriting
