@@ -58,11 +58,11 @@ App::Dochazka::REST::Model::Schedhistory - schedule history functions
 
 =head1 VERSION
 
-Version 0.252
+Version 0.253
 
 =cut
 
-our $VERSION = '0.252';
+our $VERSION = '0.253';
 
 
 
@@ -126,7 +126,7 @@ See also L<When history changes take effect>.
 
 =back
 
-For basic workflow, see C<t/007-schedule.t>.
+For basic workflow, see C<t/model/schedule.t>.
 
 
 
@@ -151,18 +151,6 @@ our @EXPORT_OK = qw( get_schedhistory );
 =head1 METHODS
 
 
-=head2 expurgate
-
-Non-destructively convert object into hashref
-
-=cut
-
-sub expurgate {
-    my ( $self ) = @_;
-    return App::Dochazka::REST::Model::Shared::expurgate( $self );
-}
-
-
 =head2 load_by_eid
 
 Class method. Given an EID, and, optionally, a timestamp, attempt to 
